#[repr(C)]pub enum AccountType {
Cash = 1,
Margin = 2,
Betting = 3,
}Expand description
An account type provided by a trading venue or broker.
Variants
Cash = 1
An account with unleveraged cash assets only.
Margin = 2
An account which facilitates trading on margin, using account assets as collateral.
Betting = 3
An account specific to betting markets.
Implementations
Sourceimpl AccountType
impl AccountType