#[repr(C)]pub enum CurrencyType {
Crypto = 1,
Fiat = 2,
CommodityBacked = 3,
}Expand description
The broad currency type.
Variants
Crypto = 1
A type of cryptocurrency or crypto token.
Fiat = 2
A type of currency issued by governments which is not backed by a commodity.
CommodityBacked = 3
A type of currency that is based on the value of an underlying commodity.
Implementations
Sourceimpl CurrencyType
impl CurrencyType