#[repr(C)]pub enum OmsType {
Unspecified = 0,
Netting = 1,
Hedging = 2,
}Expand description
The order management system (OMS) type for a trading venue or trading strategy.
Variants
Unspecified = 0
There is no specific type of order management specified (will defer to the venue OMS).
Netting = 1
The netting type where there is one position per instrument.
Hedging = 2
The hedging type where there can be multiple positions per instrument. This can be in LONG/SHORT directions, by position/ticket ID, or tracked virtually by Nautilus.
Implementations